@@ -18,7 +18,7 @@ class Nav(TagBulma):
         super().__init__()
         self["role"]="navigation"
         self["aria-label"]="main navigation"
-        self.classEnsure("navbar is-fixed-top is-black")
+        self["class"].add("navbar","is-fixed-top","is-black")
         self.title = title
         self._entries_first = {}
         self._entries_end = {}
@@ -82,8 +82,8 @@ if __name__=="__main__":
         nav.addEntry( "added page%s" %len(nav._entries_first), nothing )
 
     nav= Nav("Nav Demo")
-    # nav.addEntry( "Add a Page ", add )
-    # nav.addEntry( "exit", nothing, True )
+    nav.addEntry( "Add a Page ", add )
+    nav.addEntry( "exit", nothing, True )
 
 
     from . import _test
